@@ -22,6 +22,8 @@ Copyright (C) 2016  Salvo "LtWorf" Tomaselli
 
 #include <QDialog>
 
+#define CONFIG_RELOAD 23
+
 namespace Ui {
 class Settings;
 }
@@ -34,6 +36,7 @@ public:
     ~Settings();
 public slots:
     void accept();
+    void grab_error();
 private:
     Ui::Settings *ui;
 };
